@@ -37,8 +37,8 @@ class DataRegex(Enum):
 class DataLevel(Enum):
     """Data level name"""
 
-    RAW_DATA = "raw data"
     DERIVED_DATA = "derived data"
+    RAW_DATA = "raw data"
 
 
 class Institution(Enum, metaclass=BaseNameEnumMeta):
@@ -50,6 +50,13 @@ class Institution(Enum, metaclass=BaseNameEnumMeta):
     HUST = BaseName(name="Huazhong University of Science and Technology", abbreviation="HUST")
     NYU = BaseName(name="New York University", abbreviation="NYU")
 
+    @classmethod
+    def __modify_schema__(cls, field_schema):
+        """Adds enumNames to institution"""
+        field_schema.update(
+            enumNames=[e.value.name for e in cls],
+        )
+
 
 class Group(Enum):
     """Data collection group name"""
@@ -63,27 +70,43 @@ class Group(Enum):
 class Modality(Enum, metaclass=BaseNameEnumMeta):
     """Data collection modality name"""
 
+    CONFOCAL = BaseName(name="Confocal microscopy", abbreviation="confocal")
+    DISPIM = BaseName(name="Dual inverted selective plane illumination microscopy", abbreviation="diSPIM")
     ECEPHYS = BaseName(name="Extracellular electrophysiology", abbreviation="ecephys")
-    SPIM = BaseName(name="Selective plane illumination microscopy", abbreviation="SPIM")
+    EPHYS = BaseName(name="Electrophysiology", abbreviation="ephys")
+    EXASPIM = BaseName(name="Expansion-assisted selective plane illumination microscopy", abbreviation="exaSPIM")
     FIP = BaseName(name="Frame-projected independent-fiber photometry", abbreviation="FIP")
     FMOST = BaseName(name="Fluorescence micro-optical sectioning tomography", abbreviation="fMOST")
     HSFP = BaseName(name="Hyperspectral fiber photometry", abbreviation="HSFP")
+    ICEPHYS = BaseName(name="Intracellular electrophysiology", abbreviation="icephys")
+    MESOSPIM = BaseName(name="Mesoscale selective plane illumination microscopy", abbreviation="mesoSPIM")
     MRI = BaseName(name="Magnetic resonance imaging", abbreviation="MRI")
     OPHYS = BaseName(name="Optical physiology", abbreviation="ophys")
+    SMARTSPIM = BaseName(name="Smart selective plane illumination microscopy", abbreviation="SmartSPIM")
+    SPIM = BaseName(name="Selective plane illumination microscopy", abbreviation="SPIM")
+
+    @classmethod
+    def __modify_schema__(cls, field_schema):
+        """Adds enumNames to modality"""
+        field_schema.update(
+            enumNames=[e.value.name for e in cls],
+        )
 
 
 class ExperimentType(Enum):
-    """Experiment type name"""
-
-    CONFOCAL = "confocal"
-    DISPIM = "diSPIM"
-    EXASPIM = "exaSPIM"
-    ECEPHYS = "ecephys"
-    MESOSCOPE = "mesoscope"
-    MESOSPIM = "mesoSPIM"
-    OPHYS = "ophys"
-    OTHER = "Other"
-    SMARTSPIM = "SmartSPIM"
+    """Abbreviated name for data collection technique"""
+    
+    ECEPHYS=Modality.ECEPHYS.value.abbreviation
+    EXASPIM=Modality.EXASPIM.value.abbreviation
+    CONFOCAL=Modality.CONFOCAL.value.abbreviation
+    DISPIM=Modality.DISPIM.value.abbreviation
+    FIP=Modality.FIP.value.abbreviation
+    FMOST=Modality.FMOST.value.abbreviation
+    HSFP=Modality.HSFP.value.abbreviation
+    MESOSPIM=Modality.MESOSPIM.value.abbreviation
+    MRI=Modality.MRI.value.abbreviation
+    SMARTSPIM=Modality.SMARTSPIM.value.abbreviation
+    OTHER="Other"
 
 
 def datetime_to_name_string(d, t):
@@ -125,7 +148,7 @@ class RelatedData(AindModel):
 class DataDescription(AindCoreModel):
     """Description of a logical collection of data files"""
 
-    schema_version: str = Field("0.4.0", title="Schema Version", const=True)
+    schema_version: str = Field("0.6.0", title="Schema Version", const=True)
     license: str = Field("CC-BY-4.0", title="License", const=True)
 
     creation_time: time = Field(
@@ -147,7 +170,6 @@ class DataDescription(AindCoreModel):
         ...,
         description="An established society, corporation, foundation or other organization that collected this data",
         title="Institution",
-        enumNames=[i.value.name for i in Institution],
     )
     ror_id: Optional[str] = Field(
         None,
@@ -170,6 +192,11 @@ class DataDescription(AindCoreModel):
         description="A short name for the group of individuals that collected this data",
         title="Group",
     )
+    investigators: List[str] = Field(
+        ...,
+        description="Full name(s) of key investigators (e.g. PI, lead scientist, contact person)",
+        title="Investigators",
+    )
     project_name: Optional[str] = Field(
         None,
         description="A name for a set of coordinated activities intended to achieve one or more objectives",
@@ -193,7 +220,7 @@ class DataDescription(AindCoreModel):
     )
     experiment_type: ExperimentType = Field(
         ...,
-        description="A short name for the experimental technique used to collect this data",
+        description="An abbreviated name for the experimental technique used to collect this data",
         title="Experiment Type",
     )
     subject_id: str = Field(
