@@ -17,12 +17,12 @@ from .base import AindModel
 class SizeUnit(Enum):
     """units for sizes"""
 
-    PX = "pixel"
-    IN = "inch"
     CM = "centimeter"
+    IN = "inch"
     MM = "millimeter"
-    UM = "micrometer"
     NM = "nanometer"
+    UM = "micrometer"
+    PX = "pixel"
     NONE = "none"
 
 
@@ -41,8 +41,8 @@ class FrequencyUnit(Enum):
 class PowerUnit(Enum):
     """Power units"""
 
-    MW = "milliwatt"
     UW = "microwatt"
+    MW = "milliwatt"
 
 
 class Manufacturer(Enum):
@@ -60,6 +60,7 @@ class Manufacturer(Enum):
     FLIR = "FLIR"
     HAMAMATSU = "Hamamatsu"
     IMEC = "IMEC"
+    JULABO = "Julabo"
     LEICA = "Leica"
     LG = "LG"
     LIFECANVAS = "LifeCanvas"
@@ -72,33 +73,34 @@ class Manufacturer(Enum):
     OEPS = "OEPS"
     OLYMPUS = "Olympus"
     OPTOTUNE = "Optotune"
-    OTHER = "Other"
     OXXIUS = "Oxxius"
     QUANTIFI = "Quantifi"
     SEMROCK = "Semrock"
     THORLABS = "Thorlabs"
+    TMC = "Technical Manufacturing Corporation"
     VIEWORKS = "Vieworks"
     VORTRAN = "Vortran"
+    OTHER = "Other"
 
 
 class Coupling(Enum):
     """Laser coupling type"""
 
     FREE_SPACE = "Free-space"
-    SMF = "SMF"
-    MMF = "MMF"
+    MMF = "Multi-mode fiber"
+    SMF = "Single-mode fiber"
     OTHER = "Other"
 
 
 class DataInterface(Enum):
     """Connection between a device and a PC"""
 
-    USB = "USB"
     CAMERALINK = "CameraLink"
     COAX = "Coax"
+    ETH = "Ethernet"
     PCIE = "PCIe"
     PXI = "PXI"
-    ETH = "Ethernet"
+    USB = "USB"
     OTHER = "Other"
 
 
@@ -106,12 +108,12 @@ class FilterType(Enum):
     """Filter type"""
 
     BANDPASS = "Band pass"
-    LONGPASS = "Long pass"
-    SHORTPASS = "Short pass"
-    MULTIBAND = "Multiband"
     DICHROIC = "Dichroic"
+    LONGPASS = "Long pass"
+    MULTIBAND = "Multiband"
     ND = "Neutral density"
     NOTCH = "Notch"
+    SHORTPASS = "Short pass"
 
 
 class FilterSize(Enum):
@@ -138,10 +140,10 @@ class CameraChroma(Enum):
 class DaqChannelType(Enum):
     """DAQ Channel type"""
 
-    DO = "Digital Output"
+    AI = "Analog Input"
     AO = "Analog Output"
     DI = "Digital Input"
-    AI = "Analog Input"
+    DO = "Digital Output"
 
 
 class RelativePosition(AindModel):
@@ -194,7 +196,7 @@ class Camera(Device):
     # optional fields
     sensor_format: Optional[str] = Field(None, title="Size of the sensor")
     format_unit: Optional[str] = Field(None, title="Format unit")
-    recording_software: Optional[str] = Field(None, title="Software used to acquire camera data")
+    recording_software: Optional[str] = Field(None, title="Recording software")
 
 
 class Lens(Device):
@@ -240,12 +242,24 @@ class Filter(Device):
         None, title="Description", description="More details about filter properties and where/how it is being used"
     )
 
+class CameraTarget(Enum):
+    """Target of camera"""
+
+    BODY = "Body"
+    BOTTOM = "Bottom"
+    EYE = "Eye"
+    FACE = "Face"
+    SIDE = "Side"
+    TONGUE = "Tongue"
+    OTHER = "Other"
+
 
 class CameraAssembly(AindModel):
     """Named assembly of a camera and lens (and optionally a filter)"""
 
     # required fields
-    camera_assembly_name: str = Field(..., title="Name of this camera assembly")
+    camera_assembly_name: str = Field(..., title="Camera assembly name")
+    camera_target: CameraTarget = Field(..., title="Camera target")
     camera: Camera = Field(..., title="Camera")
     lens: Lens = Field(..., title="Lens")
 
@@ -289,6 +303,29 @@ class DAQDevice(Device):
     channels: Optional[List[DAQChannel]] = Field(None, title="DAQ channels")
 
 
+class HarpDeviceType(Enum):
+    """Harp device type"""
+
+    BEHAVIOR = "Behavior"
+    CAMERA_CONTROLLER = "Camera Controller"
+    LOAD_CELLS = "Load Cells"
+    SOUND_BOARD = "Sound Board"
+    TIMESTAMP_GENERATOR = "Timestamp Generator"
+    INPUT_EXPANDER = "Input Expander"
+
+
+class HarpDevice(DAQDevice):
+    """DAQ that uses the Harp protocol for synchronization and data transmission"""
+
+    # required fields
+    harp_device_type: HarpDeviceType = Field(..., title="Type of Harp device")
+    harp_device_version: str = Field(..., title="Device version")
+
+    # fixed values
+    manufacturer: Manufacturer = Manufacturer.OEPS
+    data_interface: DataInterface = Field("USB", const=True)
+
+
 class Laser(Device):
     """Laser module with a specific wavelength (may be a sub-component of a larger assembly)"""
 
