@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-from datetime import datetime
 from enum import Enum
 from typing import List, Optional, Union
 
@@ -22,7 +21,9 @@ from ..device import (
     DataInterface,
     Device,
     Disc,
+    HarpDevice,
     Laser,
+    Lens,
     Manufacturer,
     Monitor,
     SizeUnit,
@@ -74,33 +75,10 @@ class Coordinates3d(AindModel):
     unit: SizeUnit = Field(SizeUnit.UM, title="Position unit")
 
 
-class HarpDeviceType(Enum):
-    """Harp device type"""
-
-    BEHAVIOR = "Behavior"
-    CAMERA_CONTROLLER = "Camera Controller"
-    LOAD_CELLS = "Load Cells"
-    SOUND_BOARD = "Sound Board"
-    TIMESTAMP_GENERATOR = "Timestamp Generator"
-    INPUT_EXPANDER = "Input Expander"
-
-
-class HarpDevice(DAQDevice):
-    """DAQ that uses the Harp protocol for synchronization and data transmission"""
-
-    # required fields
-    harp_device_type: HarpDeviceType = Field(..., title="Type of Harp device")
-    harp_device_version: str = Field(..., title="Device version")
-
-    # fixed values
-    manufacturer: Manufacturer = Manufacturer.OEPS
-    data_interface: DataInterface = Field("USB", const=True)
-
-
 class ProbePort(AindModel):
     """Port for a probe connection"""
 
-    index: int = Field(..., title="Zero-based port index")
+    index: int = Field(..., title="One-based port index")
     probes: List[str] = Field(..., title="Names of probes connected to this port")
 
 
@@ -129,37 +107,24 @@ class OpenEphysAcquisitionBoard(DAQDevice):
     manufacturer: Manufacturer = Manufacturer.OEPS
 
 
-class DomeModule(AindModel):
-    """Movable module that is mounted on the ephys dome insertion system"""
-
-    # required fields
-    arc_angle: float = Field(..., title="Arc Angle", units="degrees")
-    module_angle: float = Field(..., title="Module Angle", units="degrees")
-    angle_unit: AngleUnit = Field(AngleUnit.DEG, title="Angle unit")
-
-    # optional fields
-    rotation_angle: Optional[float] = Field(0.0, title="Rotation Angle", units="degrees")
-    coordinate_transform: Optional[str] = Field(
-        None, title="Transform from local manipulator axes to rig", description="Path to coordinate transform"
-    )
-    calibration_date: Optional[datetime] = Field(None, title="Data on which coordinate transform was last calibrated")
-
-
 class Manipulator(Device):
     """Manipulator used on a dome module"""
 
     manufacturer: Literal[Manufacturer.NEW_SCALE_TECHNOLOGIES.value]
 
 
-class StickMicroscope(DomeModule):
+class StickMicroscopeAssembly(AindModel):
     """Stick microscope used to monitor probes during insertion"""
 
+    scope_assembly_name: str = Field(..., title="Scope assembly name")
     camera: Camera = Field(..., title="Camera for this module")
+    lens: Lens = Field(..., title="Lens for this module")
 
 
-class LaserModule(DomeModule):
-    """Module for optogenetic stimulation"""
+class LaserAssembly(AindModel):
+    """Assembly for optogenetic stimulation"""
 
+    laser_assembly_name: str = Field(..., title="Laser assembly name")
     manipulator: Manipulator = Field(..., title="Manipulator")
     lasers: List[Laser] = Field(..., title="Lasers connected to this module")
 
@@ -167,15 +132,15 @@ class LaserModule(DomeModule):
 class ProbeModel(Enum):
     """Probe model name"""
 
-    NP1 = "Neuropixels 1.0"
+    MI_ULED_PROBE = "Michigan uLED Probe (Version 1)"
+    MP_PHOTONIC_V1 = "MPI Photonic Probe (Version 1)"
+    NP_OPTO_DEMONSTRATOR = "Neuropixels Opto (Demonstrator)"
     NP_UHD_FIXED = "Neuropixels UHD (Fixed)"
     NP_UHD_SWITCHABLE = "Neuropixels UHD (Switchable)"
+    NP1 = "Neuropixels 1.0"
     NP2_SINGLE_SHANK = "Neuropixels 2.0 (Single Shank)"
     NP2_MULTI_SHANK = "Neuropixels 2.0 (Multi Shank)"
     NP2_QUAD_BASE = "Neuropixels 2.0 (Quad Base)"
-    NP_OPTO_DEMONSTRATOR = "Neuropixels Opto (Demonstrator)"
-    MI_ULED_PROBE = "Michigan uLED Probe (Version 1)"
-    MP_PHOTONIC_V1 = "MPI Photonic Probe (Version 1)"
 
 
 class HeadstageModel(Enum):
@@ -186,6 +151,12 @@ class HeadstageModel(Enum):
     RHD_64_CH = "Intan RHD 64-channel"
 
 
+class Headstage(Device):
+    """Headstage used with an ephys probe"""
+
+    headstage_model: Optional[HeadstageModel] = Field(None, title="Headstage model")
+
+
 class EphysProbe(Device):
     """Named probe used in an ephys experiment"""
 
@@ -194,12 +165,13 @@ class EphysProbe(Device):
 
     # optional fields
     lasers: Optional[List[Laser]] = Field(None, title="Lasers connected to this probe")
-    headstage: Optional[HeadstageModel] = Field(None, title="Headstage for this probe")
+    headstage: Optional[Headstage] = Field(None, title="Headstage for this probe")
 
 
-class EphysModule(DomeModule):
+class EphysAssembly(AindModel):
     """Module for electrophysiological recording"""
 
+    ephys_assembly_name: str = Field(..., title="Ephys assembly name")
     manipulator: Manipulator = Field(..., title="Manipulator")
     probes: List[EphysProbe] = Field(..., title="Probes that are held by this module")
 
@@ -213,17 +185,19 @@ class EphysRig(AindCoreModel):
         title="Described by",
         const=True,
     )
-    schema_version: str = Field("0.5.3", description="schema version", title="Version", const=True)
+    schema_version: str = Field("0.6.0", description="schema version", title="Version", const=True)
     rig_id: str = Field(..., description="room_stim apparatus_version", title="Rig ID")
-    ephys_modules: Optional[List[EphysModule]] = Field(None, title="Ephys probes", unique_items=True)
-    stick_microscopes: Optional[List[StickMicroscope]] = Field(None, title="Stick microscopes")
-    laser_modules: Optional[List[LaserModule]] = Field(None, title="Laser modules", unique_items=True)
+    ephys_assemblies: Optional[List[EphysAssembly]] = Field(None, title="Ephys probes", unique_items=True)
+    stick_microscopes: Optional[List[StickMicroscopeAssembly]] = Field(None, title="Stick microscopes")
+    laser_assemblies: Optional[List[LaserAssembly]] = Field(None, title="Laser modules", unique_items=True)
     cameras: Optional[List[CameraAssembly]] = Field(None, title="Camera assemblies", unique_items=True)
     visual_monitors: Optional[List[Monitor]] = Field(None, title="Visual monitors", unique_items=True)
     mouse_platform: Optional[Union[Tube, Treadmill, Disc]] = Field(None, title="Mouse platform")
     daqs: Optional[List[Union[HarpDevice, NeuropixelsBasestation, OpenEphysAcquisitionBoard, DAQDevice]]] = Field(
         None, title="Data acquisition devices"
     )
+    additional_devices: Optional[List[Device]] = Field(None, title="Additional devices", unique_items=True)
+    notes: Optional[str] = Field(None, title="Notes")
 
     @root_validator
     def validate_device_names(cls, values):
@@ -232,8 +206,8 @@ class EphysRig(AindCoreModel):
         """
 
         cameras = values.get("cameras")
-        ephys_modules = values.get("ephys_modules")
-        laser_modules = values.get("laser_modules")
+        ephys_assemblies = values.get("ephys_assemblies")
+        laser_assemblies = values.get("laser_assemblies")
         mouse_platform = values.get("mouse_platform")
         daqs = values.get("daqs")
 
@@ -245,11 +219,11 @@ class EphysRig(AindCoreModel):
         if cameras is not None:
             device_names += [c.camera.name for c in cameras]
 
-        if ephys_modules is not None:
-            device_names += [probe.name for ephys_module in ephys_modules for probe in ephys_module.probes]
+        if ephys_assemblies is not None:
+            device_names += [probe.name for ephys_assembly in ephys_assemblies for probe in ephys_assembly.probes]
 
-        if laser_modules is not None:
-            device_names += [laser.name for laser_module in laser_modules for laser in laser_module.lasers]
+        if laser_assemblies is not None:
+            device_names += [laser.name for laser_assembly in laser_assemblies for laser in laser_assembly.lasers]
 
         if mouse_platform is not None:
             device_names += [mouse_platform.name]
@@ -272,13 +246,13 @@ class EphysRig(AindCoreModel):
         actually exist
         """
 
-        ephys_modules = values.get("ephys_modules")
+        ephys_assemblies = values.get("ephys_assemblies")
         daqs = values.get("daqs")
 
-        if daqs is None or ephys_modules is None:
+        if daqs is None or ephys_assemblies is None:
             return values
 
-        probe_names = [probe.name for ephys_module in ephys_modules for probe in ephys_module.probes]
+        probe_names = [probe.name for ephys_assembly in ephys_assemblies for probe in ephys_assembly.probes]
 
         for daq in daqs:
             try:
