@@ -9,7 +9,7 @@ from typing import List, Optional, Union
 from pydantic import Field
 
 from ..base import AindCoreModel
-from ..device import CameraAssembly, DataInterface, Device, Disc, Filter, Laser, Lens, Monitor, Treadmill, Tube
+from ..device import CameraAssembly, DataInterface, Device, DAQDevice, Disc, Filter, HarpDevice, Laser, Lens, Monitor, Treadmill, Tube
 
 
 class DetectorType(Enum):
@@ -31,8 +31,8 @@ class Immersion(Enum):
     """Immersion medium name"""
 
     AIR = "air"
-    WATER = "water"
     OIL = "oil"
+    WATER = "water"
 
 
 class Detector(Device):
@@ -56,7 +56,7 @@ class OphysRig(AindCoreModel):
     """Description of an optical physiology rig"""
 
     schema_version: str = Field(
-        "0.3.0",
+        "0.3.6",
         description="schema version",
         title="Schema Version",
         const=True,
@@ -66,7 +66,7 @@ class OphysRig(AindCoreModel):
     temperature_control: Optional[bool] = Field(None, title="Temperature control")
     humidity_control: Optional[bool] = Field(None, title="Humidity control")
     vibration_control: Optional[bool] = Field(None, title="Vibration control")
-    patch_cords: List[Patch] = Field(..., title="Patch cords", unique_items=True)
+    patch_cords: Optional[List[Patch]] = Field(..., title="Patch cords", unique_items=True)
     lasers: List[Laser] = Field(..., title="Lasers", unique_items=True)
     detectors: Optional[List[Detector]] = Field(None, title="Detectors", unique_items=True)
     filters: Optional[List[Filter]] = Field(None, title="Filters", unique_items=True)
@@ -74,6 +74,9 @@ class OphysRig(AindCoreModel):
     cameras: Optional[List[CameraAssembly]] = Field(None, title="Camera assemblies", unique_items=True)
     mouse_platform: Optional[Union[Tube, Treadmill, Disc]] = Field(None, title="Mouse platform")
     visual_monitors: Optional[List[Monitor]] = Field(None, title="Visual monitors", unique_items=True)
+    daqs: Optional[List[Union[DAQDevice, HarpDevice]]] = Field(
+        None, title="Data acquisition devices"
+    )
     additional_devices: Optional[List[Device]] = Field(None, title="Additional devices", unique_items=True)
     light_path_diagram: Optional[str] = Field(
         None,
