@@ -1,6 +1,6 @@
 """ schema for various Procedures """
 
-from datetime import date, time
+from datetime import date, datetime
 from enum import Enum
 from typing import List, Optional, Union
 
@@ -8,12 +8,15 @@ from pydantic import Field
 
 from .base import AindCoreModel, AindModel
 from .device import AngleUnit, SizeUnit
+from .subject import Species
 
 
 class TimeUnit(Enum):
     """Time units"""
 
     M = "minute"
+    S = "second"
+    MS = "millisecond"
 
 
 class WeightUnit(Enum):
@@ -39,13 +42,18 @@ class SpecimenProcedureName(Enum):
     """Specimen procedure type name"""
 
     ACTIVE_DELIPIDATION = "Active delipidation"
+    CLEARING = "Clearing"
     DCM_DELIPIDATION = "DCM delipidation"
     DOUBLE_DELIPIDATION = "Double delipidation"
     EMBEDDING = "Embedding"
     FIXATION = "Fixation"
+    FIXATION_PERMEABILIZATION = "Fixation and permeabilization"
     GELATION = "Gelation"
+    HYBRIDIZATION_AMPLIFICATION = "Hybridication and amplification"
     IMMUNOSTAINING = "Immunostaining"
     SOAK = "Soak"
+    STORAGE = "Storage"
+    STRIPPING = "Stripping"
     OTHER = "Other - see notes"
 
 
@@ -53,6 +61,7 @@ class Reagent(AindModel):
     """Description of reagents used in procedure"""
 
     name: str = Field(..., title="Name")
+    source: str = Field(..., title="Source")
     rrid: Optional[str] = Field(None, title="Research Resource ID")
     lot_number: str = Field(..., title="Lot number")
     expiration_date: Optional[date] = Field(None, title="Lot expiration date")
@@ -75,6 +84,75 @@ class SpecimenProcedure(AindModel):
     notes: Optional[str] = Field(None, title="Notes")
 
 
+class StainType(Enum):
+    """Stain Types for HCR probes"""
+
+    RNA = "RNA"
+
+
+class Fluorophore(Enum):
+    """Fluorophores used in HCR"""
+
+    ALEXA_546 = "Alexa Fluor 546"
+    ALEXA_594 = "Alexa Fluor 594"
+    ALEXA_647 = "Alexa Fluor 647"
+
+class Readout(Reagent):
+    """Description of a readout"""
+
+    fluorophore: Fluorophore = Field(..., title="Fluorophore")
+    excitation_wavelength: int = Field(..., title="Excitation wavelength (nm)")
+    excitation_wavelength_unit = SizeUnit = Field(SizeUnit.NM, title="Excitation wavelength unit")
+    stain_type: StainType = Field(..., title="Stain type")
+
+class HCRReadout(Readout):
+    """Description of a readout for HCR"""
+
+    initiator_name: str = Field(..., title="Initiator name")
+
+class OligoProbe(Reagent):
+    """Description of an oligo probe"""
+
+    species: Species = Field(..., title="Species")
+    gene_name: str = Field(..., title="Gene name")
+    gene_accession_number: str = Field(
+        ..., 
+        title="Gene accession number",
+        description="NCBI accession number of the gene"
+        )
+    probe_sequences: List[str] = Field(..., title="Probe sequences")
+    readout: Readout = Field(..., title="Readout")
+    channel_index: int = Field(..., title="Channel index")
+
+class HCRProbe(OligoProbe):
+    """Description of a HCR probe"""
+
+    initiator_name: str = Field(..., title="Initiator name")
+    readout: HCRReadout = Field(..., title="Readout")
+
+
+class HybridizationChainReaction(AindModel):
+    """Description of an HCR round""" 
+
+    round_index: int = Field(..., title="Round index")
+    start_time: datetime = Field(..., title="Round start time")
+    end_time: datetime = Field(..., title="Round end time")
+    HCR_probes: List[HCRProbe] = Field(..., title="HCR probes")
+    other_probes: Optional[List[OligoProbe]] = Field(None, title="Other probes")
+    probe_concentration: float = Field(..., title="Probe concentration (M)")
+    probe_concentration_unit: str = Field("M", title="Probe concentration unit")
+    intrument_id: str = Field(..., title="Instrument ID")
+
+
+class HCRSeries(SpecimenProcedure):
+    """Description of series of HCR rounds for mFISH"""
+
+    codebook_name: str = Field(..., title="Codebook name")
+    number_of_rounds: int = Field(..., title="Number of round")
+    hcr_rounds: List[HybridizationChainReaction] = Field(..., title="Hybridization Chain Reaction rounds")
+    strip_qc_compatible: bool = Field(..., title="Strip QC compatible")
+
+
 class Side(Enum):
     """Side of animal"""
 
@@ -86,8 +164,8 @@ class ProtectiveMaterial(Enum):
     """Name of material applied to craniotomy"""
 
     DURAGEL = "Duragel"
-    SORTA_CLEAR = "SORTA-clear"
     KWIK_CAST = "Kwik-Cast"
+    SORTA_CLEAR = "SORTA-clear"
     OTHER = "Other - see notes"
 
 
@@ -132,10 +210,10 @@ class SubjectProcedure(AindModel):
 class CraniotomyType(Enum):
     """Name of craniotomy Type"""
 
-    VISCTX = "Visual Cortex"
-    WHC = "Whole hemisphere craniotomy"
     THREE_MM = "3 mm"
     FIVE_MM = "5 mm"
+    VISCTX = "Visual Cortex"
+    WHC = "Whole hemisphere craniotomy"
     OTHER = "Other"
 
 
@@ -168,14 +246,15 @@ class Craniotomy(SubjectProcedure):
     dura_removed: Optional[bool] = Field(None, title="Dura removed")
     protective_material: Optional[ProtectiveMaterial] = Field(None, title="Protective material")
     workstation_id: Optional[str] = Field(None, title="Workstation ID")
-    recovery_time: Optional[time] = Field(None, title="Recovery time")
+    recovery_time: Optional[float] = Field(None, title="Recovery time")
+    recovery_time_unit: Optional[TimeUnit] = Field(TimeUnit.M, title="Recovery time unit")
 
 
 class HeadframeMaterial(Enum):
     """Headframe material name"""
 
-    TITANIUM = "Titanium"
     STEEL = "Steel"
+    TITANIUM = "Titanium"
     WHITE_ZIRCONIA = "White Zirconia"
 
 
@@ -213,7 +292,7 @@ class InjectionMaterial(AindModel):
         description="Short name used to reference the plasmid",
     )
     genome_copy: Optional[float] = Field(None, title="Genome copy")
-    titer: Optional[float] = Field(None, title="Titer (gc/mL", units="gc/mL")
+    titer: Optional[float] = Field(None, title="Titer (gc/mL)", units="gc/mL")
     titer_unit: Optional[str] = Field("gc/mL", title="Titer unit")
     prep_lot_number: Optional[str] = Field(None, title="Preparation lot number")
     prep_date: Optional[date] = Field(
@@ -229,7 +308,8 @@ class Injection(SubjectProcedure):
     """Description of an injection procedure"""
 
     injection_materials: List[InjectionMaterial] = Field(None, title="Injection material", unique_items=True)
-    recovery_time: Optional[time] = Field(None, title="Recovery time")
+    recovery_time: Optional[float] = Field(None, title="Recovery time")
+    recovery_time_unit: Optional[TimeUnit] = Field(TimeUnit.M, title="Recovery time unit")
     injection_duration: Optional[float] = Field(None, title="Injection duration")
     injection_duration_unit: Optional[TimeUnit] = Field(TimeUnit.M, title="Injection duration unit")
     workstation_id: Optional[str] = Field(None, title="Workstation ID")
@@ -240,8 +320,8 @@ class RetroOrbitalInjection(Injection):
     """Description of a retro-orbital injection procedure"""
 
     procedure_type: str = Field("Retro-orbital injection", title="Procedure type", const=True)
-    injection_volume: float = Field(..., title="Injection volume (nL)", units="nL")
-    injection_volume_unit: str = Field("nL", title="Injection volume unit")
+    injection_volume: float = Field(..., title="Injection volume (uL)", units="uL")
+    injection_volume_unit: VolumeUnit = Field(VolumeUnit.UL, title="Injection volume unit")
     injection_eye: Side = Field(..., title="Injection eye")
 
 
@@ -390,7 +470,7 @@ class Perfusion(SubjectProcedure):
 class Procedures(AindCoreModel):
     """Description of all procedures performed on a subject"""
 
-    schema_version: str = Field("0.7.0", description="schema version", title="Version", const=True)
+    schema_version: str = Field("0.7.4", description="schema version", title="Version", const=True)
     subject_id: str = Field(
         ...,
         description="Unique identifier for the subject. If this is not a Allen LAS ID, indicate this in the Notes.",
@@ -413,6 +493,13 @@ class Procedures(AindCoreModel):
                 SubjectProcedure,
             ]
         ]
-    ] = Field([], title="Subject Procedures", unique_items=True)
-    specimen_procedures: Optional[List[SpecimenProcedure]] = Field([], title="Specimen Procedures", unique_items=True)
+    ] = Field(None, title="Subject Procedures", unique_items=True)
+    specimen_procedures: Optional[
+        List[
+            Union[
+                HCRSeries,
+                SpecimenProcedure,
+            ]
+        ]
+    ] = Field(None, title="Specimen Procedures", unique_items=True)
     notes: Optional[str] = Field(None, title="Notes")
